@@ -3,7 +3,7 @@ ldapobject.py - wraps class _ldap.LDAPObject
 
 See http://www.python-ldap.org/ for details.
 
-\$Id: ldapobject.py,v 1.126 2011/07/22 20:27:40 stroeder Exp $
+\$Id: ldapobject.py,v 1.129 2011/12/02 09:42:50 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -85,7 +85,8 @@ class SimpleLDAPObject:
     self._ldap_object_lock.acquire()
     if __debug__:
       if self._trace_level>=1:
-        self._trace_file.write('*** %s - %s\n%s\n' % (
+        self._trace_file.write('*** %s %s - %s\n%s\n' % (
+          repr(self),
           self._uri,
           '.'.join((self.__class__.__name__,func.__name__)),
           pprint.pformat((args,kwargs))
@@ -201,7 +202,7 @@ class SimpleLDAPObject:
 
   def simple_bind_s(self,who='',cred='',serverctrls=None,clientctrls=None):
     """
-    simple_bind_s([who='' [,cred='']]) -> None
+    simple_bind_s([who='' [,cred='']]) -> 4-tuple
     """
     msgid = self.simple_bind(who,cred,serverctrls,clientctrls)
     resp_type, resp_data, resp_msgid, resp_ctrls = self.result3(msgid,all=1,timeout=self.timeout)
@@ -223,7 +224,7 @@ class SimpleLDAPObject:
 
   def sasl_interactive_bind_s(self,who,auth,serverctrls=None,clientctrls=None,sasl_flags=ldap.SASL_QUIET):
     """
-    sasl_interactive_bind_s(who, auth) -> None
+    sasl_interactive_bind_s(who, auth [,serverctrls=None[,clientctrls=None[,sasl_flags=ldap.SASL_QUIET]]]) -> None
     """
     return self._ldap_call(self._l.sasl_interactive_bind_s,who,auth,RequestControlTuples(serverctrls),RequestControlTuples(clientctrls),sasl_flags)
 
